@@ -1,7 +1,8 @@
-__version__ = '0.1.6'
+__version__ = "0.1.7"
 """Library version"""
 
 import stactools.core
+
 from .dataset import Dataset
 from .errors import CogifyError
 
@@ -10,7 +11,8 @@ stactools.core.use_fsspec()
 
 def register_plugin(registry):
     from . import commands
+
     registry.register_subcommand(commands.create_goes_command)
 
 
-__all__ = [Dataset, CogifyError]
+__all__ = ["Dataset", "CogifyError"]
