@@ -1,8 +1,8 @@
-import click
 import os.path
 
-from stactools.goes import stac
-from stactools.goes import cog
+import click
+
+from stactools.goes import cog, stac
 
 
 def create_goes_command(cli):
@@ -10,15 +10,16 @@ def create_goes_command(cli):
     def goes():
         pass
 
-    @goes.command("create-item",
-                  short_help="Creates a STAC item from a GOES netcdf file")
+    @goes.command(
+        "create-item", short_help="Creates a STAC item from a GOES netcdf file"
+    )
     @click.argument("href")
     @click.argument("destination")
     @click.option(
         "-c",
         "--cogify",
         is_flag=True,
-        help="Convert the netcdf into COGs. COG Asset HREFs will be local paths"
+        help="Convert the netcdf into COGs. COG Asset HREFs will be local paths",
     )
     def create_item(href, destination, cogify):
         """Creates a STAC item from a GOES netcdf file.
@@ -30,8 +31,7 @@ def create_goes_command(cli):
             cogs = cog.cogify(href, destination)
         else:
             cogs = {}
-        item = stac.create_item(
-            [stac.ProductHrefs(nc_href=href, cog_hrefs=cogs)])
+        item = stac.create_item([stac.ProductHrefs(nc_href=href, cog_hrefs=cogs)])
         path = os.path.join(destination, f"{item.id}.json")
         item.set_self_href(path)
         item.validate()
