@@ -1,21 +1,21 @@
-from dataclasses import dataclass
 import logging
-import re
 import os
-from typing import Callable, List, Optional, Dict, TypeVar
+import re
+from dataclasses import dataclass
+from typing import Callable, Dict, List, Optional, TypeVar
 
 import fsspec
+import rasterio
 from h5py import File
 from pystac import Item
-from pystac.extensions.projection import ProjectionExtension
 from pystac.extensions.eo import EOExtension
+from pystac.extensions.projection import ProjectionExtension
 from pystac.extensions.raster import RasterExtension
-import rasterio
-
 from stactools.core.io import ReadHrefModifier
-from stactools.goes import cog, __version__
-from stactools.goes.dataset import Dataset
+
+from stactools.goes import __version__, cog
 from stactools.goes.bands import get_channel_resolution
+from stactools.goes.dataset import Dataset
 from stactools.goes.enums import ImageType, PlatformId
 from stactools.goes.errors import GOESRProductHrefsError
 from stactools.goes.file_name import ABIL2FileName
@@ -48,14 +48,13 @@ class ProductHrefs:
 
     Key is the variable name, value is the href.
     """
+
     @staticmethod
-    def validate_single_observation(
-            product_hrefs: List["ProductHrefs"]) -> None:
+    def validate_single_observation(product_hrefs: List["ProductHrefs"]) -> None:
         """Validates that all hrefs are from a single observation."""
-        item_ids = set([
-            ABIL2FileName.from_href(ph.nc_href).get_item_id()
-            for ph in product_hrefs
-        ])
+        item_ids = set(
+            [ABIL2FileName.from_href(ph.nc_href).get_item_id() for ph in product_hrefs]
+        )
         if len(item_ids) != 1:
             raise GOESRProductHrefsError(
                 f"ProductHrefs represent multiple observations: {','.join(item_ids)}"
@@ -76,10 +75,9 @@ def normalize_cmi_cog_assets(item: Item) -> None:
     """
     # Create a Dict of channel (e.g. 'C01') to a Dict of the
     # asset keys for each of the CMIP and MCMIP products.
-    channel_to_cmi_cog_asset_keys: Dict[int, Dict[ProductAcronym,
-                                                  List[str]]] = {}
+    channel_to_cmi_cog_asset_keys: Dict[int, Dict[ProductAcronym, List[str]]] = {}
     for asset_key in item.assets:
-        # Ingore nc assets
+        # Ignore nc assets
         if item.assets[asset_key].href.endswith("nc"):
             continue
         target_product: Optional[ProductAcronym] = None
@@ -93,35 +91,29 @@ def normalize_cmi_cog_assets(item: Item) -> None:
             if m:
                 channel = int(m.group(1))
             elif target_product == ProductAcronym.CMIP:
-                raise Exception(
-                    f"CMIP expected to have info in asset_key: {asset_key}")
+                raise Exception(f"CMIP expected to have info in asset_key: {asset_key}")
             if channel is not None:
                 if channel not in channel_to_cmi_cog_asset_keys:
                     channel_to_cmi_cog_asset_keys[channel] = {}
-                if target_product not in channel_to_cmi_cog_asset_keys[
-                        channel]:
+                if target_product not in channel_to_cmi_cog_asset_keys[channel]:
                     channel_to_cmi_cog_asset_keys[channel][target_product] = []
-                channel_to_cmi_cog_asset_keys[channel][target_product].append(
-                    asset_key)
+                channel_to_cmi_cog_asset_keys[channel][target_product].append(asset_key)
 
     # Deduplicate products that contain the same data.
     # Convert asset keys to "CMI" instead of "CMIP" or "MCMIP"
     # Append the resolution to the asset key
-    for channel, product_to_asset_keys in channel_to_cmi_cog_asset_keys.items(
-    ):
+    for channel, product_to_asset_keys in channel_to_cmi_cog_asset_keys.items():
         if len(product_to_asset_keys) > 1:
             res_in_meters = get_channel_resolution(channel)
             if res_in_meters != 2000:
-                res_in_km = int(res_in_meters /
-                                1000) if res_in_meters != 500 else 0.5
+                res_in_km = int(res_in_meters / 1000) if res_in_meters != 500 else 0.5
                 # If this is channel 2, 3 or 5, then the CMIP data
                 # contains a higher resolution version of the data.
                 # Modify the asset keys accordingly.
                 for asset_key in product_to_asset_keys[ProductAcronym.CMIP]:
                     asset = item.assets[asset_key]
                     asset.title = f"{asset.title} (full resolution)"
-                    new_key = asset_key.replace("CMIP",
-                                                "CMI") + f"_{res_in_km}km"
+                    new_key = asset_key.replace("CMIP", "CMI") + f"_{res_in_km}km"
                     item.assets[new_key] = asset
                     item.assets.pop(asset_key)
             else:
@@ -150,10 +142,12 @@ def create_item(
     first entry of product_hrefs.
 
     backoff_func: A backoff function that can be used for exponential backoff
-        of data reading for throttling messages occuring during highly parallelized jobs.
+        of data reading for throttling messages occurring during highly parallelized jobs.
     """
     dataset: Dataset
-    _rhm: ReadHrefModifier = read_href_modifier if read_href_modifier is not None else lambda x: x
+    _rhm: ReadHrefModifier = (
+        read_href_modifier if read_href_modifier is not None else lambda x: x
+    )
     with_backoff = backoff_func if backoff_func else lambda f: f()
 
     if len(product_hrefs) == 0:
@@ -174,28 +168,32 @@ def create_item(
 
     start_datetime = dataset.global_attributes.start_datetime
 
-    item = Item(id=dataset.file_name.get_item_id(),
-                geometry=dataset.geometry.footprint,
-                bbox=dataset.geometry.bbox,
-                datetime=start_datetime,
-                properties={})
+    item = Item(
+        id=dataset.file_name.get_item_id(),
+        geometry=dataset.geometry.footprint,
+        bbox=dataset.geometry.bbox,
+        datetime=start_datetime,
+        properties={},
+    )
 
-    item.common_metadata.platform = PlatformId.to_stac_value(
-        dataset.file_name.platform)
+    item.common_metadata.platform = PlatformId.to_stac_value(dataset.file_name.platform)
     item.common_metadata.instruments = ["ABI"]
 
     item.stac_extensions.append(
-        "https://stac-extensions.github.io/processing/v1.0.0/schema.json")
+        "https://stac-extensions.github.io/processing/v1.0.0/schema.json"
+    )
     item.properties["processing:software"] = {"stactools-goes": __version__}
 
     item.properties["goes:system-environment"] = dataset.file_name.system.value
     item.properties["goes:image-type"] = ImageType.to_stac_value(
-        dataset.file_name.image_type)
+        dataset.file_name.image_type
+    )
     item.properties["goes:mode"] = dataset.file_name.mode.value
     item.properties["goes:processing-level"] = "L2"
     if dataset.file_name.mesoscale_number:
         item.properties["goes:mesoscale-image-number"] = int(
-            dataset.file_name.mesoscale_number.value)
+            dataset.file_name.mesoscale_number.value
+        )
 
     # Projection
 
@@ -222,7 +220,8 @@ def create_item(
 
             for variable, cog_href in hrefs.cog_hrefs.items():
                 cog_asset_key, cog_asset_def = product.get_cog_asset_def(
-                    file_name, variable)
+                    file_name, variable
+                )
                 asset = cog_asset_def.create_asset(cog_href)
 
                 # Get COG metadata
@@ -231,17 +230,13 @@ def create_item(
                 def get_cog_metadata() -> None:
                     with rasterio.open(_rhm(cog_href)) as ds:
                         # Set tansform and shape if needed
-                        if not projection.shape or ds.shape[
-                                0] != projection.shape[0]:
-                            ProjectionExtension.ext(asset).shape = list(
-                                ds.shape)
+                        if not projection.shape or ds.shape[0] != projection.shape[0]:
+                            ProjectionExtension.ext(asset).shape = list(ds.shape)
                             ProjectionExtension.ext(asset).transform = list(
-                                ds.transform)
+                                ds.transform
+                            )
 
-                        dtypes = {
-                            i: dtype
-                            for i, dtype in zip(ds.indexes, ds.dtypes)
-                        }
+                        dtypes = {i: dtype for i, dtype in zip(ds.indexes, ds.dtypes)}
                         dtype = dtypes[1]
 
                         raster = RasterExtension.ext(asset)
@@ -249,6 +244,7 @@ def create_item(
                         band = raster.bands[0]
                         assert band
                         band.data_type = dtype
+                        assert band.data_type
                         if band.data_type.startswith("float"):
                             band.nodata = ds.nodata
                         else:
@@ -272,16 +268,17 @@ def create_item(
 
 
 def create_item_from_href(
-        href: str,
-        read_href_modifier: Optional[ReadHrefModifier] = None,
-        cog_directory: Optional[str] = None,
-        backoff_func: Optional[BackoffFunc] = None) -> Item:
+    href: str,
+    read_href_modifier: Optional[ReadHrefModifier] = None,
+    cog_directory: Optional[str] = None,
+    backoff_func: Optional[BackoffFunc] = None,
+) -> Item:
     """Creates a pystac.Item from a GOES netcdf file.
 
     cog_directory: The directory COGs will be saved to,
         if generating COGs.
     backoff_func: A backoff function that can be used for exponential backoff
-        of data reading for throttling messages occuring during highly parallelized jobs.
+        of data reading for throttling messages occurring during highly parallelized jobs.
     """
     cogs: Optional[Dict[str, str]] = None
     if cog_directory:
@@ -290,4 +287,5 @@ def create_item_from_href(
     return create_item(
         product_hrefs=[ProductHrefs(nc_href=href, cog_hrefs=cogs)],
         read_href_modifier=read_href_modifier,
-        backoff_func=backoff_func)
+        backoff_func=backoff_func,
+    )
